#
# spec file for package xfce4-terminal
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xfce4-terminal
Version:        0.8.5.1
Release:        1.1
Summary:        Terminal Emulator for the Xfce Desktop Environment
License:        GPL-2.0+
Group:          System/X11/Terminals
Url:            http://docs.xfce.org/apps/terminal/start
Source0:        http://archive.xfce.org/src/apps/xfce4-terminal/0.8/%{name}-%{version}.tar.bz2
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exo-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libxfce4ui-2)
BuildRequires:  pkgconfig(vte-2.91)
Recommends:     %{name}-lang

%description
xfce4-terminal is a lightweight and easy to use terminal emulator for the Xfce
desktop environment. Its major features include a simple configuration
interface, the ability to use multiple tabs with terminals within a single
window, the possibility to have a pseudo-transparent terminal background, and a
compact mode where both the menubar and the window decorations are hidden which
helps to save space on the desktop.

%lang_package

%prep
%setup -q

%build
%configure
make %{?_smp_mflags} V=1

%install
%make_install

# create a list of localized man directories, these need to be owned
(
    printf '%%%%defattr(-,root,root)\n'
    cd '%{buildroot}'
    for dir in ".%{_mandir}/"*; do
        [ -d "${dir}" ] || continue
        case ${dir##*/} in
            man*)   continue ;;
            *)      lang="${dir##*/}"
                    printf "%%%%dir %%%%lang(%%s) %%s\n" "${lang}" "${dir#.}"
                    for subdir in "${dir}/"*; do
                        [ -d "${subdir}" ] || continue
                        printf "%%%%dir %%%%lang(%%s) %%s\n" "${lang}" \
                            "${subdir#.}"
                    done
                    ;;
        esac
    done
) >> %{name}.lang

%find_lang %{name} --with-man %{?no_lang_C}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING HACKING NEWS README THANKS
%{_bindir}/xfce4-terminal
%dir %{_datadir}/xfce4
%{_datadir}/xfce4/terminal
%{_datadir}/applications/xfce4-terminal.desktop
%dir %{_datadir}/gnome-control-center
%{_datadir}/gnome-control-center/default-apps
%{_mandir}/man1/xfce4-terminal.1*

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Fri Jun 16 2017 sor.alexei@meowr.ru
- Update to version 0.8.5.1:
  * Fix font settings load (bxo#13574).
* Sat May 20 2017 lazy.kent@opensuse.org
- Update to 0.8.5.
  * Do not change drop-down window size when zooming in/out.
  * Create terminal of desired size instead of default size of
    80x24: this allows to avoid resizing the terminal right after
    creation.
  * Use default terminal geometry when --geometry parameter is used
    but its value only contains X and Y offsets.
  * Improve label layout in preferences dialog: restrict max width
    to 80 chars.
  * Add --minimize command line option.
  * Calculate screen dimensions properly when having multiple
    monitors.
  * Prevent clipboard from being filled with garbage.
  * Resolve deprecation warnings: gtk_show_uri_on_window,
    gdk_screen_make_display_name, gdk_screen_get_width/height.
  * Silence most of deprecation warnings that are not resolved.
  * Make Preferences dialog app-global - the same dialog window
    will be used by multiple terminal windows.
  * Remove large space to the left of tab text when the text is too
    short (this allows tabs to be smaller).
  * Gtk3 required version bumped to 3.16.0.
  * Fix memory leaks.
  * Close Find dialog when closing parent terminal window.
  * Close Set Title dialog when closing its corresponding tab.
  * Translation updates: Catalan, Chinese (Taiwan), German, Greek,
    Hebrew, Kazakh, Lithuanian, Norwegian Bokmål, Polish,
    Portuguese (Brasil), Russian, Serbian, Slovenian, Swedish,
    Thai, Ukrainian.
- Changes in 0.8.4.
  * Fixes related to fullscreen state and showing/hiding window in
    drop-down mode.
  * Fix incorrect window positioning when started in fullscreen
    state.
  * Add a separate Show window borders setting for drop-down mode.
  * Make Double click chars setting more compact in the UI.
  * Do not force show drop-down window on screen size change.
  * Background image improvements: scale huge images to 8K when
    loading from file (this reduces memory consumption); print a
    warning if failed to open an image.
  * Expose Slim tabs setting to Preferences.
  * Translation updates: Bulgarian, Chinese (China), Chinese
    (Taiwan), Croatian, Czech, Danish, Dutch, Finnish, French,
    Japanese, Kazakh, Korean, Lithuanian, Malay, Norwegian Bokmål,
    Polish, Portuguese, Russian, Slovak, Spanish, Ukrainian.
* Wed Jan 25 2017 lazy.kent@opensuse.org
- Update to 0.8.3.
  * Fix incorrect initial position of a drop-down window under
    Unity.
  * min-height/width CSS properties not available in old GTK
    versions.
  * Remove redundant set_window_geometry_hints() call.
  * Add Help button to Set Title dialog.
  * GtkColorButton show-editor property only available starting
    with GTK 3.20.
  * Watch for screen size changes to update drop-down window size
    or position accordingly. Size change signal is emitted when
    monitor resolution is changed or another monitor is connected.
  * Make slim tabs even more slim.
  * Translation updates: Chinese (China), Lithuanian, Thai.
- Changes in 0.8.2.
  * Add hidden option MiscSlimTabs to override huge gtk3 tabs
    style.
  * Temporarily show menubar with F10 even if it's hidden.
  * Add "Run custom command instead of shell" feature.
  * Fix segfault on dragging last window tab to another window.
  * Add option for ambigouos-width characters (narrow/wide).
  * Don't show palette when editing palette colors in preferences.
  * Fix move dropdown window to monitor with pointer behavior.
  * When un-closing a tab, set it active if it was active when it
    got closed.
  * Set locale as vte encoding in case encoding is not set in prefs
    (support for running 'LANG=charset xfce4-terminal').
  * Allow to specify text selection background color.
  * Allow to select system-wide monospace font in preferences.
  * Fix Alt+n shortcuts when starting with several tabs.
  * Add option to automatically copy selection to the clipboard.
  * Support background image transparency.
  * Fix deprecation warnings.
  * Support setting drop-down status bar icon with --icon option.
  * Fix terminal geometry hints for GTK < 3.19.5.
  * Translation updates: Arabic, Bulgarian, Catalan, Chinese
    (China), Chinese (Taiwan), Croatian, Czech, Danish, Deutsch,
    Dutch, French, Hebrew, Italian, Japanese, Kazakh, Korean,
    Lithuanian, Malay, Norwegian Bokmål, Polish, Portuguese,
    Portuguese (Brazil), Russian, Slovak, Spanish, Swedish,
    Ukrainian.
* Fri Nov  4 2016 lazy.kent@opensuse.org
- Update to 0.8.1.
  * Fix Ctrl press recognition for opening URIs with Ctrl+click.
  * Set preferences dialog type hint to make it show on top.
  * Fix toggling fullscreen mode with F11 for a drop-down window.
  * Allow setting of empty shortcut for goto-tab actions.
  * Resolve window manager warning: Buggy client sent a
    _NET_ACTIVE_WINDOW message with a timestamp of 0.
  * Fix drop-down window visibility check.
  * Resolve some deprecation warnings.
  * Fix drop-down window not shown on different workspaces.
  * Add MiscUseShiftArrowsToScroll hidden option to allow
    Shift+arrows one-line scroll (off by default).
  * Allow user-defined color palettes - should be located under
    ~/.config/xfce4/terminal/colorschemes/.
  * Set window hints properly; show columns/rows when resizing.
  * Translation updates: Chinese (China), Croatian, English
    (Australia), French, Kazakh, Lithuanian, Malay, Polish,
    Spanish, Ukrainian.
* Sun Oct 23 2016 lazy.kent@opensuse.org
- Update to 0.8.0.
  * Move context menu zoom actions to a sub-menu.
  * Fix some build-time deprecation warnings.
  * Fix hiding of dropdown terminal.
  * Fix setting focus to dropdown window.
  * Fix "Always keep window on top" setting that was ignored.
  * Show missing action icons in dropdown mode.
  * Add rewrap on resize control option to Preferences.
  * Add --show/hide-scrollbar command line options.
  * Implement background image support; add BackgroundImageShading
    setting for background image mode.
  * Remove "Scrolling single line" option as the functionality is
    implemented by vte.
  * Add mouse-wheel binding for zoom: Shift + Ctrl + wheel up/down
    controlled by a hidden option MiscMouseWheelZoom - ON by
    default.
  * Do not set DISPLAY variable in non-X11 environments (e.g.
    Wayland).
  * Fix memory leak when showing preferences dialog.
  * Fix menubar text not visible with some themes.
  * Fix vte "resize-window" signal handler.
  * Fix notebook widget transparency seen under Unity.
  * Make vte transparency work in Gnome under both X11 and Wayland.
  * Show warning and disable Opacity control in Preferences if
    window manager does not support compositing.
  * Fix tab activity indication.
  * Fix geometry positioning when a negative offset is used.
  * Quote all file names/URIs drag-and-dropped to the terminal.
  * Fix cursor focus.
  * Translation updates: Bulgarian, Chinese (Taiwan), Croatian,
    Czech, Dutch, English (Australia), French, German, Hebrew,
    Japanese, Korean, Lithuanian, Malay, Polish, Portuguese,
    Portuguese (Brazil), Russian, Slovak, Spanish, Swedish, Thai,
    Ukrainian.
* Tue Oct 11 2016 lazy.kent@opensuse.org
- Update to 0.6.92.
  * Fix geometry setting (default ot provided via the command line
    option) for GTK 3.20.5.
  * Remove "Update utmp/wtmp records when command is launched"
    setting since the feature has been removed from vte.
  * Replace deprecated GtkTable with GtkGrid in Preferences.
  * Disable Zoom-In/Out actions on reaching zoom limits.
  * Do not allow Reset in Read-Only mode.
- Changes in 0.6.91.
  * Fix solarized light theme colors.
  * Fix huge size of Set Title dialog under wayland.
  * Support wayland (resolve crashes and warnings).
  * Improve handling negative x/y geometry positions.
  * Fix scrollbar/menubar/toolbar incorrectly shown in dropdown
    mode after window has been minimized/restored.
  * Add ability to save terminal contents to a file.
  * Prepare for upcoming vte regex API change.
  * Fix Vte-WARNING related to regex.
  * Implement Read-Only mode (user input disabled).
  * Fix input focus lost issue after exiting a console app (e.g.
    nano).
  * Fix cursor not blinking when fg color = bg color.
  * Enable configuration of a new tab working directory:
    MiscDefaultWorkingDir option. If it is set (non-empty value),
    new tabs and windows will use the dir specified as their
    working dir. Otherwise, the behavior remains as is (current dir
    will be used).
  * Do not un-close tab that was moved to another window.
  * Properly enable/disable F1 shortcut.
  * Fix Preferences window hidden in fullscreen mode.
  * Do not un-close tab that was detached to create another window.
  * Fix incorrect update of go-to-tab menu.
  * Add Undo Close Tab functionality: stores closed tabs in
    chronological order; restores working directory, position in
    the tabbar, custom title.
  * Add Close Other Tabs functionality.
  * Make terminal always drop down from the top of the screen.
  * Create Alt+digit shortcuts if they haven't been loaded from
    config file.
  * Fix dropdown window animation; remove viewport widget.
  * Code cleanup: Do not declare or define a reserved identifier.
  * Add urgent bell functionality: MiscBellUrgent option.
  * When detaching a tab, make new window respect original
    geometry.
  * Fix possible buffer overwrite issue.
  * Keep rows number constant when adding/removing widgets such as
    toolbar or tabbar.
  * Make a tab close button icon a bit smaller.
  * Add ability to switch tabs with a mouse scroll wheel.
  * Fix selection characters override.
  * Fix resize logic with tab.
  * Translation updates: Bulgarian, Catalan, Chinese (China),
    Chinese (Taiwan), Croatian, Czech, Dutch, English (Australia),
    German, Hebrew, Japanese, Korean, Portuguese (Brazil), Russian,
    Serbian, Spanish, Swedish, Turkish, Ukrainian.
* Wed Aug 10 2016 lazy.kent@opensuse.org
- Update to 0.6.90.
  * Migrate to GTK+3/VTE3.
  * Fix closing wrong tabs with Ctrl+Shift+W.
  * Make close tab shortcut work for single tab.
  * Add Ctrl+Shift+PgUp/PgDn shortcuts to move tabs left/right.
  * Add support for unlimited scrollback.
  * Fix actions applied to wrong tab after closing another one.
  * Update intltool.
  * Add Ctrl+Shift+S hotkey to set title.
  * Expose MiscTabCloseMiddleClick option to Preferences.
  * Fix terminal window not moved to foreground when using --tab
    option.
  * Respect Display window borders setting in drop-down mode.
  * Apply opacity setting by chaging background color alpha value.
  * Prevent characters from being hidden by block cursor.
  * Fix in drop-down mode, "100%% width" isn't really 100%%.
  * Add ShortcutsNoHelpkey option to disable F1 (help) shortcut key
    and expose it to Preferences.
  * Add support for magnet links.
  * Expose MiscMouseAutohide option to Preferences.
  * Fix terminal crash when starting with --geometry.
  * Add ability to zoom in/out by pressing Ctrl +/-; add --font and
  - -zoom command line options.
  * Expand zoom level.
  * Add hidden option MiscMiddleClickOpensUri to control whether
    middle click opens URI: if FALSE, Ctrl + left click is used for
    that; default is FALSE.
  * Fix compilation for vte < 0.44.
  * Remove emulation setting and input methods menu as they are not
    supported by vte.
  * Do not allow creating multiple Set Title dialog windows.
  * Remove Help button and add icon to Close button in Set Title
    dialog.
  * Add an icon to the search dialog close button.
  * Rename UI setting from Transparency to Opacity.
  * Update terminal website address in the About dialog.
  * Fix crash on moving a tab from one window to another.
  * Add tooltip for the Find toolbar button.
  * Add setting to allow cursor blinking to Preferences.
  * Add setting to change cursor shape to Preferences.
  * Fix typo in the preferences dialog.
  * Add some new encodings taken from gnome-terminal.
  * Fix crash on setting encoding.
  * Fix detach tab functionality with GTK>=3.16.
  * Fix segfault when right/middle click on tab bar.
  * Translation updates: Arabic, Asturian, Bulgarian, Catalan,
    Chinese (China), Chinese (Taiwan), Croatian, Czech, Danish,
    Dutch, English (Australia), Esperanto, Finnish, French, German,
    Greek, Hebrew, Hungarian, Icelandic, Indonesian, Italian,
    Japanese, Kazakh, Korean, Lithuanian, Malay, Norwegian Bokmål,
    Polish, Portuguese, Portuguese (Brazil), Romanian, Russian,
    Serbian, Slovak, Slovenian, Spanish, Swedish, Thai, Turkish,
    Ukrainian.
- Change BuildRequires: pkgconfig(gtk+-3.0), pkgconfig(vte-2.91).
- Remove BuildRequires: fdupes, update-desktop-files.
- Don't install ChangeLog (it is useless).
- Clean up the spec.
* Fri Dec 27 2013 gber@opensuse.org
- update to version 0.6.3
  - improve URL matching (bxo#7959, bxo#9800)
  - fix encoding menu creation (bxo#10395)
  - added light solarized colorscheme (bxo#10286)
  - fixed wrong foreground color in solarized dark (bxo#10285)
  - fix terminal session restore (bxo#9732)
  - translation updates
- drop obsolete
  xfce4-terminal-fix-up-the-encoding-menu-creation.patch
* Wed Oct 23 2013 lazy.kent@opensuse.org
-  Add xfce4-terminal-fix-up-the-encoding-menu-creation.patch: Fix
  up the encoding menu creation (bxo#10395).
* Sun May  5 2013 gber@opensuse.org
- update to version 0.6.2:
  - autotools updates
  - fix toolbars -> toolbar in docs
  - check display for the real display, not display.screen
  - display checking on drop-down windows
  - fix format warning
  - only call g_type_init on glib < 2.36
  - translation updates
* Mon Mar 11 2013 coolo@suse.com
- also obsolete Terminal-doc or you get an error on update
* Tue Jan  1 2013 gber@opensuse.org
- update to version 0.6.1:
  - add drop-down window support with --drop-down parameter, this
    allows xfce4-terminal to start 1 game-console like window
  - rename Go menu to Tabs
  - load default Alt+N accelerators on first startup
  - make single tab accelerator insensitive again
  - rename clear scrollbar to reset
  - fix crash when showing toolbar 2nd time
  - don't check for version and help in parameters parsing
  - remove Report Bug menu entry
  - hide search dialog on delete to avoid crash
  - set minimum tab label size to 10 chars
  - make right-click tab menu more functional
  - stop activity timeout when destroying a screen
  - rename $TERM to emulation and use new preference to avoid
    migration crashes
  - fix the tab re-use option when running from shortcut
  - allow underscore and + in email address
  - use new GPL license address
  - allow setting the geometry in the preferences
  - translation updates
* Fri Dec 28 2012 gber@opensuse.org
- provide/obsolete Terminal-lang correctly
* Fri Dec 28 2012 gber@opensuse.org
- Terminal was renamed to xfce4-terminal
